#---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
## Thomas König (2015) Kanzler, Minister and Sachverständige. Eine Unersuchung der Bedeutung von Vertrauen für die Delegation von Reformen am Beispiel der Hartz=Reformen, PVS, 56(2): 182-210
## All analyses were run on OS X 10.10.5 (Yosemite) using R version 3.1.3 (2015-03-09) 
## The number of recommendations of the economic council were extracted manually from their annual reports (Gutachten des Sachverständigenrates zur Begutachtung der gesamtwirtschaflichen Entwicklung in Deutschland). For more inforation on the manual coding please refer to the above article. 
##------------------------------------------------------------------------------------------------------------------------------------------------

##@@@------------------------------------------------------------------------------------------------------------------------------------------------
## Replication file 1: use this script to:
	## create Figure 1 on p. 194 which indicates the number of SVR (Sachverständigenrat) recommendations for the economic, finance and labor policy areas for the period 1990-2011.
	## Note that a detailed descritpion for each variable in the dataset svr_recommendations.rda is provided at the botto mof this script and in the documentaion file svr_recommendations_info.pdf in the folder "svr recommendations data"
	## Note: check "2.replication file_Figure 2, Figure 3.R"  to create Figure 2 and Figure 3 from the above article.
## For further information please contact Mariyana Angelova: mariyana.angelova@univie.ac.at  OR mariyana.angelova@gmail.com
## 31.07.2017
##@@@------------------------------------------------------------------------------------------------------------------------------------------------

## clean worsking space
rm(list = ls(all = TRUE))

## set working directory (choose a folder where you have saved all replication files and data)
	setwd("~/Dropbox/Replication Files/2015/Koenig 2015 PVS")

## load redommendation recom (object recom) 
	load(file="./svr recommendations data/svr_recommendations.rda")
	#recom<-read.csv(file="./svr_original.csv")
	recom.backup<-recom
	names(recom)
	
## create a dummy which indicated whether finance, economy or social are among the most important policy areas tackled in each individual recommendation. Note that one recommendation main refer to more than one policy area!
	## most important policy fields are saved in the variable policy_field1_original. The policy areas saved in policy_field2_original and policy_field3_original were considered as less important by the coders.
	
	unique(recom$policy_field1_original)
		
	## finance
		fin1<-grep("finanz", recom$policy_field1_original)
		fin2<-grep("geld", recom$policy_field1_original)
		fin3<-grep("eu-bezug", recom$policy_field1_original) ## eu-bezug counted towards finance and economy
	
		fin<-unique(c(fin1,fin2, fin3))

		recom$most.important.finance<-0
		recom$most.important.finance[recom$policy_field1_original==""]<-NA
		recom$most.important.finance[fin]<-1
		table(recom$most.important.finance)
		unique(recom[,c('most.important.finance',"policy_field1_original")])
	
	## economy
		econ1<-grep("wirt", recom$policy_field1_original)
		econ2 <-grep("eu-bezug", recom$policy_field1_original) # eu-bezug counted towards finance and economy
		notecon <-grep("landwirt", recom$policy_field1_original) # exclude landwirtschaft
		econ<-unique(c(econ1, econ2))
		econ<-setdiff(econ,notecon)

		recom$most.important.economy<-0
		recom$most.important.economy[recom$policy_field1_original==""]<-NA
		recom$most.important.economy[econ]<-1
		table(recom$most.important.economy)
		unique(recom[,c('most.important.economy',"policy_field1_original")])

	## social	
		social1<-grep("arbeit", recom$policy_field1_original)
		social2 <-grep("sozial", recom$policy_field1_original) 
		social3 <-grep("altersvers", recom$policy_field1_original) 
		social<-unique(c(social1, social2, social3))

		recom$most.important.social<-0
		recom$most.important.social[recom$policy_field1_original==""]<-NA
		recom$most.important.social[social]<-1
		table(recom$most.important.social)
		unique(recom[,c('most.important.social',"policy_field1_original")])
	
	

##--------------------------------------------------------------------------
## Create Figure 1, which plots the number of SVR recomendations by year
##-------------------------------------------------------------------------

## keep only recommendations!
	recom<-recom[recom$separate.topic==1,]
	dim(recom)


	## figure specifications
		nov<-11/12
		years.nov.label<-paste( "Nov",c(1990:2009))
		years.nov<-c(1990:2009)+nov

	## specify total number of recommendations per year		
		total<-as.numeric(table(as.factor(recom$start.year)))
		years<-as.numeric(names(table(as.factor(recom$start.year))))		
	## specify total number of finance related recommendations per year
		finance<-as.numeric(table(as.factor(recom$start.year)[recom$most.important.finance==1]))
	## specify total number of economy related recommendations per year	
		economy<-as.numeric(table(as.factor(recom$start.year)[recom$most.important.economy==1]))
	## specify total number of social related recommendations per year	
		social<-as.numeric(table(as.factor(recom$start.year)[recom$most.important.social==1]))
	
## Plot Figure 1, page 194: "Empfehlungen des Sachverständigenrates für Wirtschaft (1990-2009)"
pdf("./replicated_figures/Figure1_svr_recommendations.pdf",width=14,height=6)
	par(mar=c(6,4,4,3))
	plot(c(1990+nov,2009+nov),c(0,100),type="n", main="Empfehlung des Sachverständigenrates für Wirtschaft (1990-2009)", ylab="Anzahl der Empfehlungen", xlab="", xaxt="n", yaxt="n",ylim=c(0,110),las=1 )
	## Cabinets: Kohl V 11.1994 - 10.1998, Schröder 1998 -2002, Schröder 2002 -2005, Merkel 2005-2009
	mtext(c("Kohl IV","Kohl V","Schröder I","Schröder II","Merkel I"), side=1,line=4.5, outer=F, at=c(1993,1996.5, 2000.9, 2004.5,2007.9), cex=1, col="black")

## total recommendations
	lines(years+nov,total, col="black", type=c("l"), lwd=1.5, lty=1)
	points(years+nov,total,pch=19,cex=1.1)
## econ
	lines(years +nov,economy, col="green", type=c("l"), lwd=1.5,lty=2)
	points(years +nov, economy,pch=24,cex=1.1, col="green")
# finance
	lines(years +nov,finance, col="blue", type=c("l"), lwd=1.5,lty=3)
	points(years +nov,finance,pch=21,cex=1.1, col="blue")
# social
	lines(years +nov,social, col="red", type=c("l"), lwd=1.5,lty=4)
	points(years +nov,social ,pch=22,cex=1.1, col="red")
# axis
	axis(1, at=years.nov, labels=years.nov.label, cex.axis=0.8, las=2)
	axis(2, at=seq(0, 110, by = 10), labels=seq(0, 110, by = 10), cex.axis=0.8, las=1)
## Elections in germany: 02.12.1990 # 16.10.1994 # 27.09.1998 # 22.09.2002 # 18.09.2005 # 27.09.2009
	abline(v=c(1990+12/12,1994+10/12,1998+9/12,2002+9/12,2005+9/12,2009+9/12), col = "darkgray", lty=1)
	legend(1991.13,110, c("Alle Empfehlungen","Wirtschaft", "Finanzen","Arbeit und Soziales"), col=c("black","green","blue","red"),lty=c(1,2,3,4),pch=c(19,24,21,22), cex=0.8)
	#abline(h=seq(0, 110, by = 10), col="gray", lty=2) # horizontal lines for yeasier reading of the graph
dev.off()



##------------------------------------	
## ----------------------------------------------------------------------------
## Codebook: Detailed information about all variables in the dataset "recom"
## ----------------------------------------------------------------------------
##------------------------------------	
	
	head(recom)
	
	## The unit of observation in the dataset "recom" are individual recommendations. 
	## We identified the text which contains policy recommendations. Each title/subtitle (caption) is counted as one recommendation. 
	## Note that we did not consider descriptions of the current economic situation. 
	## We extracted all recomendations and saved these in files called 1.E1990/91.txt, etc (E stands for "Empfehlung" (recommendation)). These can be found in folder documents/SVR_SVR Gutachten/text format_recommendations only
	
	
	## VARIABLES
	recom$id.recommendation ## Id of the expert recommendation. This id indicates the year of the expert recommendation and the number of the recommendation (sequential numbering)
	recom$years ## years of the expert report
	recom$start.year ## first year of the expert report
	recom$end.year	## last year of the expert report
	recom$separate.topic # dummy for a recommendation, 1= recommendation, 0=not a recommendation, just a caption without underlying text.
	recom$n.words ## number of words in the recommendation. Basically the number of words below each caption, which is counted as one recommendation.
	recom$paragraph.number.offcial 	## The expert reports have paragraph numbering. We saved the numbers of the paragraphs which belong to one recommendation
	
## Each document follows some hierarchical structure, where we can identify differnet levels of the title/subtitles(captions). We recoreded all levels in the text, starting with the highest level - the chapter, which is followed by caption level 1, caption level 2 until caption level 5. 
## for example, recommendation 1990005 appears under chapter "Eine kürzere Fassung", caption level 1 (subtitle) "Auf dem Wege zur wirtschaftlichen Einheit Deutschlands" and caption level 2 (subsubtitle) "Die Aufgabe in den neuen Bundesländern - den Aufholprozess breit in Gang setzen" and covers paragrapgs: 71-75 (on page 16-17 of the expert recommendation from 1990-1991 (see 1-1990/91.pdf in folder "documents/SVR_SVR Gutachten/pdf format_originals"))
	recom[recom$id.recommendation==1990005,] ## show recommendation 19990005
	recom$chapter ## the name of the chapter to which the recommendation belongs
	recom$caption.level1  ## the name of the caption at level 1 (subtitle) to which the recommendation belongs
	recom$caption.level2  ## the name of the caption at level 2 (sub subtitle) to which the recommendation belongs
	recom$caption.level3  ## the name of the caption at level 3 (sub sub subtitle) to which the recommendation belongs
	recom$caption.level4 ## the name of the caption at level 4 (sub sub sub subtitle) to which the recommendation belongs
	recom$caption.level5 ## the name of the caption at level 5 (sub sub sub sub subtitle) to which the recommendation belongs
	recom$caption.level  ## the caption level of the recommendation, 0=chapter, 1=caption level 1, 2=caption level 2, 3=caption level 3, 4=caption level 4, 5=caption level 5
		
## Each recommendation was assigned to one of of the 31 policy categories listed in document: SVR_recommendations_categories.xlsx
## Each recommendation could be assigned to one or several policy categories. Coders were asked to identify the most important policy area(S) (given the recommendation text) and save these in the variable policy_field1_original. Additional policy areas, to which the recommendation is related are mentioned in the variables: policy_field2_original abd policy_field3_original
	recom$policy_field1_original ## most important policy areas
	recom$policy_field2_original ## additional policy area
	recom$policy_field3_original ## additional policy area
	
## this script created the following three variables which indicate whether finance, economy, or social are among the most important policy areas tackled by each recommendation.
	recom$most.important.finance ## dummy, which indicates whether one of the central aspects of the recommendation tackle financial issues, 1 stays for yes, 0 stays for no
	recom$most.important.economy ## dummy, which indicates whether one of the central aspects of the recommendation tackle economic issues, 1 stays for yes, 0 stays for no
	recom$most.important.social ## dummy, which indicates whether one of the central aspects of the recommendation tackle social issues, 1 stays for yes, 0 stays for no
	




