
##---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
## Thomas König (2015) Kanzler, Minister and Sachverständige. Eine Unersuchung der Bedeutung von Vertrauen für die Delegation von Reformen am Beispiel der Hartz=Reformen, PVS, 56(2): 182-210
## All analyses were run on OS X 10.10.5 (Yosemite) using R version 3.1.3 (2015-03-09) 
## To count the Hartz I-IV reforms frequences in the selected political texts a dictionary with Hartz I-IV keywords was created using Yoshikoder (see hartz_reforms.ykd in  the folder called "hartz reforms keywords"). Yoshikoder can be downloaded here: http://conjugateprior.org/software/yoshikoder/.  The dictionary with Hartz I-IV reforms keywords was used as an input in the software JFreq, which was used to create the frequences of Hartz I-IV reforms keywords in the political texts. JFreq can be downloaded here http://conjugateprior.org/software/jfreq/. 
##------------------------------------------------------------------------------------------------------------------------------------------------

##@@@------------------------------------------------------------------------------------------------------------------------------------------------
## Replication file 2: use this script to:
	## create Figure 2 on p. 195 which indicates the number of Harz-I-IV keywords/1000 words for Council Recommendations (Sachverständigenrat) and for the Government Economic Reports  (1990-2011)
	## create Figure 3 on p. 197 which indicages the number of Hartz I-IV keywords/1000 words for the party manifestos of CDU/CSU, SPD, FDP, Grüne, Linke (1990-2009) and for the coalition agreements issued in the period between 1990-2009 (1991, 1994, 1998, 2002, 2005, 2009)
	## here we will use the frequencies of Hartz-I-IV reform keywords, which are saved in folder "frequency results". !!! To replicate these frequences follow the guidlines in the replication documentation file called "0.Replication_documentation.pdf". For this purpose you will need to download and install Yoshikoder and JFreq and input the text format of the political documents which are saved in folder "documents". (Note that the JFreq and Yoshikoder sofwares run with older Java versions.) 	
## For further information please contact Mariyana Angelova: mariyana.angelova@univie.ac.at  OR mariyana.angelova@gmail.com
## 31.07.2017
##@@@------------------------------------------------------------------------------------------------------------------------------------------------


## clean up
rm(list = ls(all = TRUE))

## set working directory (choose a folder where you have saved all replication files and data)
setwd("~/Dropbox/Replication Files/2015/Koenig 2015 PVS")


## load frequences data. 
	## jwb (economic reports of the government)
	breg<-read.csv(file="./frequency results/jwb_hartz_reforms_frequences.csv", sep=',', header=T)
	head(breg)
	## coalition agreements
	ca<-read.csv(file="./frequency results/ca_hartz_reforms_frequences.csv", sep=',', header=T)
	head(ca)
	## party manifestos
	manifesto<-read.csv(file="./frequency results/pm_hartz_reforms_frequences.csv", sep=';', header=T)
	head(manifesto)
	## svr (economic council recommendations)
	recom<-read.csv(file="./frequency results/svr_hartz_reforms_frequences.csv", sep=';', header=T)
	head(recom)
		## adjust variabes
		recom$first.year<-recom$year
		recom$second.year<-recom$year+1
		## first year of the Council Report
		recom$year<-recom$first.year

####---------------------------
### Control for length of text
####---------------------------

## count HartzI-IV keywords per 1000 words
	recom$share<-(recom$hartz_reforms_sum /recom$total_text_words )*1000
	breg$share<-(breg$hartz_reforms_sum /breg$total_text_words )*1000
	manifesto$share<-(manifesto$hartz_reforms_sum /manifesto$total_text_words )*1000
	ca$share<-(ca$hartz_reforms_sum /ca$total_text_words )*1000

## year specifications	
	nov<-11/12 # time of the year for SVR recommendations
	feb<-2/12 # time of the year for the economic reports of the government 
	years.nov<-c(1990:2010)+nov
	years.feb<-c(1990:2011)+feb
	years<-sort(c(years.feb, years.nov))
	years.feb.label<-paste( "Feb",c(1990:2011))
	years.nov.label<-paste( "Nov",c(1990:2010))
	years.label<-sort(c(years.feb.label, years.nov.label))
	years.label.sort<-years.label[c(1,23,2,24,3,25,4,26,5,27,6,28,7,29,8,30,9,31,10,32,11,33,12,34,13,35,14,36,15,37,16,38,17,39,18,40,19,41,20,42,21,43,22)]

##---------------------------------------------------------------------------------------------------------------
## plot Figure 2), page. 195: "SVR-Gutachten & Jahreswirtschaftsberichte, Hartz I-IV Stichwörter pro 1000 Wörter"
##---------------------------------------------------------------------------------------------------------------
pdf("./replicated_figures/Figure2_hartz_reforms_keywords_in_svr_jwb.pdf",width=10,height=6)
par(mar=c(6,5,4,3))
	plot(c(1990, 2011), c(0,20),type="n",xlab="",xaxt="n",las=1,ylab="N Hartz I-IV Stichwörter pro 1000 Wörter", main='SVR-Gutachten & Jahreswirtschaftsberichte \n Hartz I-IV Stichwörter pro 1000 Wörter')	
## council recommendations
	lines(recom$year+nov,recom$share, col="black", type=c("l"), lwd=1.5, lty=1)
	points(recom$year+nov,recom$share,pch=19,cex=1.1)
## government reports
	lines(breg$year+feb,breg$share, col="red", type=c("l"), lwd=1.5, lty=3)
	points(breg$year+feb,breg$share,pch=18,cex=1.3, col="red")
	axis(1,at=years,labels=years.label.sort, cex.axis=0.6, las=2)	
## cabinets: Kohl V 11.1994 - 10.1998, Schröder 1998 -2002, Schröder 2002 -2005, Merkel 2005-2009
	## elections 12.1990,10.1994, 09.1998, 09.2002, 09.2005, 09.2009
	abline(v=c(1990+12/12,1994+10/12,1998+9/12,2002+9/12,2005+9/12,2009+9/12), col = "darkgray", lty=2)
	mtext(c("Kohl IV","Kohl V","Schröder I","Schröder II","Merkel I", "Merkel II"), side=1,line=4, outer=F, at=c(1993,1996.5, 2000.9, 2004.5,2007.9, 2011), cex=0.8, col="black")
## legend
	legend(1990.13,18, c("SVR-Gutachten","JWB"), col=c("black","red"),lty=c(1,2),pch=c(19,18), cex=0.8)
dev.off()


##---------------------------------------------------------------------------------------------------------------
## plot Figure 3), page 197: "Parteiprogramme & Koalitionsverträge, Hartz I-IV- Stichwörter pro 1000 Wörter"
##---------------------------------------------------------------------------------------------------------------
	## monthly specifications as indicators when a new government started
		oct<-10/12
		jan<-1/12
		sept<-9/12
		june<-6/12
	## get party specific Hartz IV reform frequences
		party.union<-manifesto[manifesto$party=="union",]
		party.spd<-manifesto[manifesto$party=="spd",]
		party.fdp<-manifesto[manifesto$party=="fdp",]
		party.gruene<-manifesto[manifesto$party=="gruene",]
		party.linke<-manifesto[manifesto$party=="linke",]
pdf("./replicated_figures/Figure3_hartz_reforms_keywords_in_party_manifestos_coalition_agreements.pdf",width=10,height=6)

par(mar=c(6,5,4,3))
plot(c(1990, 2011),c(0,20),type="n",xlab="",xaxt="n",las=1,ylab="N Hartz I-IV Stichwörter pro 1000 Wörter", main="Parteiprogramme & Koalitionsverträge, Hartz I-IV- Stichwörter pro 1000 Wörter", ylim=c(0,20))
##  party programms
	## set 09.1990, all other programs set them to appear in june 
## CDU-CSU
	lines(party.union$year+c(sept,june,june,june,june,june),party.union$share, col="black", type=c("l"), lwd=3.5, lty=1)
	points(party.union$year+c(sept,june,june,june,june,june),party.union$share,pch=19,cex=1.1)
## SPD
	lines(party.spd$year+c(sept,june,june,june,june,june),party.spd$share, col="red", type=c("l"), lwd=3.5, lty=2)
	points(party.spd$year+c(sept,june,june,june,june,june),party.spd$share,pch=20,cex=1.1, col="red")
## FDP
	lines(party.fdp$year+c(sept,june,june,june,june,june),party.fdp$share, col="orange", type=c("l"), lwd=3.5, lty=3)
	points(party.fdp$year+c(sept,june,june,june,june,june),party.fdp$share,pch=21,cex=1.1, col="orange")
## Gruene
	lines(party.gruene$year+c(sept,june,june,june,june,june),party.gruene$share, col="green", type=c("l"), lwd=3.5, lty=4)
	points(party.gruene$year+c(sept,june,june,june,june,june),party.gruene$share,pch=22,cex=1.1, col="green")
## Linke
	lines(party.linke$year+c(sept,june,june,june,june,june),party.linke$share, col="pink", type=c("l"), lwd=3.5, lty=5)
	points(party.linke$year+c(sept,june,june,june,june,june),party.linke$share,pch=23,cex=1.1, col="pink")
	axis(1,at=1990:2011,labels=1990:2011, cex.axis=0.8, las=2)
## Cabinets: Kohl V 11.1994 - 10.1998, Schröder 1998 -2002, Schröder 2002 -2005, Merkel 2005-2009
	abline(v=c(1990+11/12,1994+9/12,1998+8/12,2002+8/12,2005+8/12,2009+8/12), col = "darkgray", lty=2)
	mtext(c("Kohl IV","Kohl V","Schröder I","Schröder II","Merkel I", "Merkel II"), side=1,line=4, outer=F, at=c(1993,1996.5, 2000.9, 2004.5,2007.9, 2011), cex=0.8, col="black")
## coalition agreements
	## 12.01.1991; ## 11.11.1994; ## 20.10.1998; ## 16.10.2002; ## 11.11.2005; ## 26.10.2009
	lines(ca$year+c(jan,nov,oct,oct,nov,oct),ca$share, col="blue", type=c("l"), lwd=1.5, lty=3)
	points(ca$year+c(jan,nov,oct,oct,nov,oct),ca$share,pch=18,cex=1.3, col="blue")
## legend
	legend(1990.13,18, c("CDU/CSU","SPD", "FDP", "Grüne", "Linke", "KV"), col=c("black","red","orange","green", "pink", "blue"),lty=c(1,2,3,4,5),pch=c(19,20,21,22,23), cex=0.8)
dev.off()

















